@@ -1,5 +1,30 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
+/*
+ *  oafd: OAF CORBA dameon.
+ *
+ *  Copyright (C) 1999, 2000 Red Hat, Inc.
+ *  Copyright (C) 1999, 2000 Eazel, Inc.
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License as
+ *  published by the Free Software Foundation; either version 2 of the
+ *  License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors: Elliot Lee <sopwith@redhat.com>,
+ *
+ */
+
 #include "config.h"
+#include "oaf-i18n.h"
 
 #include <popt.h>
 #include <signal.h>
@@ -12,6 +37,7 @@
 
 #include "oafd.h"
 #include "ac-query-expr.h"
+#include "od-utils.h"
 
 #ifdef OAF_DEBUG
 static void debug_queries (void);
@@ -28,22 +54,22 @@ static int server_ac = 0, ior_fd = -1, server_ns = 1;
 static struct poptOption options[] = {
 
 	{"od-source-dir", '\0', POPT_ARG_STRING, &od_source_dir, 0,
-	 "Directory to read .oafinfo files from", "DIRECTORY"},
+	 N_("Directory to read .oafinfo files from"), N_("DIRECTORY")},
 	{"od-domain", '\0', POPT_ARG_STRING, &od_domain, 0,
-	 "Domain of ObjectDirectory", "DOMAIN"},
+	 N_("Domain of ObjectDirectory"), N_("DOMAIN")},
 
 	{"ac-activate", '\0', POPT_ARG_NONE, &server_ac, 0,
-	 "Serve as an ActivationContext (default is as an ObjectDirectory only)",
+	 N_("Serve as an ActivationContext (default is as an ObjectDirectory only)"),
 	 NULL},
 
 
 	{"ior-output-fd", '\0', POPT_ARG_INT, &ior_fd, 0,
-	 "File descriptor to write IOR to", "FD"},
+	 N_("File descriptor to write IOR to"), N_("FD")},
 
 #ifdef OAF_DEBUG
 
 	{"evaluate", '\0', POPT_ARG_STRING, &ac_evaluate, 0,
-	 "Query expression to evaluate", "EXPRESSION"},
+	 N_("Query expression to evaluate"), N_("EXPRESSION")},
 #endif
 
 	POPT_AUTOHELP {NULL}
@@ -64,6 +90,10 @@ main (int argc, char *argv[])
 	FILE *fh;
 	struct sigaction sa;
 
+	/* internationalization. */
+        bindtextdomain (PACKAGE, OAF_LOCALEDIR);
+        textdomain (PACKAGE);
+
 	memset (&sa, 0, sizeof (sa));
 	sa.sa_handler = SIG_IGN;
 	sigaction (SIGPIPE, &sa, NULL);
@@ -83,10 +113,17 @@ main (int argc, char *argv[])
 		CORBA_ORB_resolve_initial_references (orb, "RootPOA", &ev);
 	{
 		char *env_od_source_dir;
+		char *gnome_env_od_source_dir;
+                char *config_file_od_source_dir;
+		GString *gnome_od_source_dir;
+                char **gnome_dirs;
 		GString *real_od_source_dir;
+                int i;
 
 		real_od_source_dir = g_string_new (OAFINFODIR);
-		env_od_source_dir = getenv ("OAF_INFO_PATH");
+		env_od_source_dir = g_getenv ("OAF_INFO_PATH");
+		gnome_env_od_source_dir = g_getenv ("GNOME_PATH");
+                config_file_od_source_dir = od_utils_load_config_file ();
 
 		if (od_source_dir) {
 			g_string_append_c (real_od_source_dir, ':');
@@ -97,6 +134,25 @@ main (int argc, char *argv[])
 			g_string_append (real_od_source_dir,
 					 env_od_source_dir);
 		}
+                if (config_file_od_source_dir) {
+			g_string_append_c (real_od_source_dir, ':');
+			g_string_append (real_od_source_dir,
+					 config_file_od_source_dir);                        
+                }
+		if (gnome_env_od_source_dir) {
+                        gnome_dirs = g_strsplit (gnome_env_od_source_dir, ":", -1);
+                        gnome_od_source_dir = g_string_new("");
+                        for (i=0; gnome_dirs[i]; i++) {
+                                g_string_append (gnome_od_source_dir,
+                                                 gnome_dirs[i]);
+                                g_string_append (gnome_od_source_dir,
+                                                 "/share/oaf:");
+                        }
+                        g_strfreev (gnome_dirs);
+			g_string_append_c (real_od_source_dir, ':');
+			g_string_append (real_od_source_dir,
+					 gnome_od_source_dir->str);
+		}
 
 		od = OAF_ObjectDirectory_create (root_poa, od_domain,
                                                  real_od_source_dir->str,
