@@ -1,4 +1,28 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
+/*
+ *  oafd: OAF CORBA dameon.
+ *
+ *  Copyright (C) 1999, 2000 Red Hat, Inc.
+ *  Copyright (C) 1999, 2000 Eazel, Inc.
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License as
+ *  published by the Free Software Foundation; either version 2 of the
+ *  License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors: Elliot Lee <sopwith@redhat.com>,
+ *
+ */
+
 #include "config.h"
 
 #include <stdio.h>
@@ -130,34 +154,34 @@ od_dump_list (impl_POA_OAF_ObjectDirectory * od)
 			 od->attr_servers._buffer[i].iid,
 			 od->attr_servers._buffer[i].server_type,
 			 od->attr_servers._buffer[i].location_info);
-		for (j = 0; j < od->attr_servers._buffer[i].attrs._length;
+		for (j = 0; j < od->attr_servers._buffer[i].props._length;
 		     j++) {
-			OAF_Attribute *attr =
+			OAF_Property *prop =
 				&(od->attr_servers._buffer[i].
-				  attrs._buffer[j]);
-			g_print ("    %s = ", attr->name);
-			switch (attr->v._d) {
-			case OAF_A_STRING:
-				g_print ("\"%s\"\n", attr->v._u.value_string);
+				  props._buffer[j]);
+			g_print ("    %s = ", prop->name);
+			switch (prop->v._d) {
+			case OAF_P_STRING:
+				g_print ("\"%s\"\n", prop->v._u.value_string);
 				break;
-			case OAF_A_NUMBER:
-				g_print ("%f\n", attr->v._u.value_number);
+			case OAF_P_NUMBER:
+				g_print ("%f\n", prop->v._u.value_number);
 				break;
-			case OAF_A_BOOLEAN:
+			case OAF_P_BOOLEAN:
 				g_print ("%s\n",
-					 attr->v.
+					 prop->v.
 					 _u.value_boolean ? "TRUE" : "FALSE");
 				break;
-			case OAF_A_STRINGV:
+			case OAF_P_STRINGV:
 				g_print ("[");
 				for (k = 0;
-				     k < attr->v._u.value_stringv._length;
+				     k < prop->v._u.value_stringv._length;
 				     k++) {
 					g_print ("\"%s\"",
-						 attr->v._u.
+						 prop->v._u.
 						 value_stringv._buffer[k]);
 					if (k <
-					    (attr->v._u.
+					    (prop->v._u.
 					     value_stringv._length - 1))
 						g_print (", ");
 				}
@@ -380,7 +404,7 @@ impl_OAF_ObjectDirectory_activate (impl_POA_OAF_ObjectDirectory * servant,
 
 	if (!CORBA_Object_is_nil (retval, ev)
 	    && !CORBA_Object_non_existent (retval, ev)
-	    && !(flags & OAF_FLAG_IGNORE_EXISTING))
+	    && !(flags & OAF_FLAG_PRIVATE))
 		return CORBA_Object_duplicate (retval, ev);
 
 	if (flags & OAF_FLAG_EXISTING_ONLY)
